#! /bin/sh
#
# SWITCHaai Federation Metadata (1.1 and 1.2)
# 
# Shibboleth Target 1.1:
#   Sites File: http://wayf1.switch.ch/SWITCHaai/sites.xml
#   Trust File: http://wayf1.switch.ch/SWITCHaai/trust.xml
#
# Shibboleth Target 1.2:
#  Sites File: http://www.switch.ch/aai/federation/pilot/sites-1.2.xml
#  Trust File: http://www.switch.ch/aai/federation/pilot/trust-1.2.xml
#
# SWITCHaai Signer certificate:
#  http://www.switch.ch/aai/federation/pilot/SWITCHpki-wayf1.switch.ch.crt
#
# Valery Tschopp - SWITCH 
# set -x

##
# Configure directories and path
##
SHIB_HOME=/opt/shibboleth-1.2.1
SHIB_ETC=$SHIB_HOME/etc/shibboleth
LD_LIBRARY_PATH=$SHIB_HOME/lib
export LD_LIBRARY_PATH

##
# Configure sites and trust URLs and local names
##
SITES_URL=http://www.switch.ch/aai/federation/pilot/sites-1.2.xml
TRUST_URL=http://www.switch.ch/aai/federation/pilot/trust-1.2.xml
SITES_NAME=$SHIB_ETC/sites.switchaai.xml
TRUST_NAME=$SHIB_ETC/trust.switchaai.xml

##
# Configure signer certificate
##
SIGNER_CRT=$SHIB_ETC/wayf1.switch.ch.crt


############################################
# Get new versions

NOW=`date +%Y%m%d%H%M`

echo "Retrieve Sites file: $SITES_URL"
$SHIB_HOME/bin/siterefresh \
    --url $SITES_URL \
    --out $SITES_NAME.$NOW \
    --schema $SHIB_ETC \
    --cert $SIGNER_CRT
# abort on error
[ "$?" -ne "0" ] && exit $?

echo "Retrieve Trust file: $TRUST_URL"
$SHIB_HOME/bin/siterefresh \
    --url $TRUST_URL \
    --out $TRUST_NAME.$NOW \
    --schema $SHIB_ETC \
    --cert $SIGNER_CRT
# abort on error
[ "$?" -ne "0" ] && exit $?

############################################
# Make backups
[ ! -d "$SHIB_ETC/backup" ] && mkdir $SHIB_ETC/backup

# Compare new to existing.  If same, delete new, if not replace existing
# and backup new.
for file in $SITES_NAME $TRUST_NAME ; do
    if [ -r $file.$NOW ] ; then
        if cmp -s $file.$NOW $file ; then
            echo "Unchanged $file.$NOW"
            rm -f $file.$NOW
        else
            echo "New $file.$NOW"
            cp $file.$NOW $SHIB_ETC/backup
            mv -f $file.$NOW $file
        fi
    else
        echo "Retrieval of $file.$NOW failed."
    fi
done

